# Exporters

Exporting is only supported for acknowledged standards.

Currently xradar can export:

- [](#odim_h5)
- [](#cfradial2)

## ODIM_H5

### to_odim

With {class}`~xradar.io.export.to_odim` an xradar {py:class}`datatree:datatree.DataTree`
can be saved to an ODIM_H5 file (v2.2 at the moment).

## CfRadial2

### to_cfradial2

With {class}`~xradar.io.export.to_cfradial2` an xradar {py:class}`datatree:datatree.DataTree`
can be saved to a CfRadial2-like file.
